pub struct CpuLocation {
pub cpu: usize,
pub core: usize,
pub package: usize,
pub numa_node: usize,
}Expand description
A description of the CPU’s location in the machine topology.
Fields
cpu: usizeHolds the CPU id. This is the most granular field and will distinguish
among hyper-threads.
core: usizeHolds the core id on which the cpu is located.
package: usizeHolds the package or socket id on which the cpu is located.
numa_node: usizeHolds the NUMA node on which the cpu is located.