pub struct LocalExecutor { /* private fields */ }
Single-threaded executor.

The executor can only be run on the thread that created it.

Examples

use glommio::LocalExecutor;

let local_ex = LocalExecutor::default();

local_ex.run(async {
    println!("Hello world!");
});

In many cases, use of LocalExecutorBuilder will provide more configuration options and more ergonomic methods. See LocalExecutorBuilder::spawn for examples.

Implementations

Enable or disable task stall detection at runtime

Examples
use glommio::{DefaultStallDetectionHandler, LocalExecutor};

let local_ex =
    LocalExecutor::default().detect_stalls(Some(Box::new(DefaultStallDetectionHandler {})));

Returns a unique identifier for this Executor.

Examples
use glommio::LocalExecutor;

let local_ex = LocalExecutor::default();
println!("My ID: {}", local_ex.id());

Removes a task queue.

The task queue cannot be removed if there are still pending tasks.

Runs the executor until the given future completes.

Examples
use glommio::{LocalExecutor, Task};

let local_ex = LocalExecutor::default();

let res = local_ex.run(async {
    let task = glommio::spawn_local(async { 1 + 2 });
    task.await * 2
});

assert_eq!(res, 6);