pub struct PriorityBump<T> { /* private fields */ }Expand description
Allows the priority of the DeadlineQueue to be temporarily bumped.
The priority is bumped for as long as this object is alive. This is useful in situations where, despite having a deadline we may never want the priority to fall too low.
This could be because a user started watching the process, a shutdown sequence was initiated, etc.